@@ -20,7 +20,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <qfile.h>
+#include <QFile>
 
 #include <kstandarddirs.h>
 
@@ -45,8 +45,8 @@ BackupProfile::~BackupProfile()
 
 void BackupProfile::load()
 {
-    QString filename = locateLocal( "appdata", _lastSavedName + ".bp");
-    
+    QString filename = KStandardDirs::locateLocal( "appdata", _lastSavedName + ".bp");
+
     FILE* fptr = fopen( QFile::encodeName(filename), "r" );
     if ( !fptr ) {
         return;
@@ -105,11 +105,11 @@ void BackupProfile::load()
 
 void BackupProfile::save()
 {
-    QString filename = locateLocal( "appdata", _lastSavedName + ".bp");
+    QString filename = KStandardDirs::locateLocal( "appdata", _lastSavedName + ".bp");
     bool    null_name_p = _lastSavedName.isEmpty();
 
     _lastSavedName = _name.copy();
-    
+
     if( TRUE == null_name_p ){
       return;
     }
@@ -122,17 +122,17 @@ void BackupProfile::save()
     }
 
     fprintf( fptr, "%d\n", 1 ); // Version
-    fprintf( fptr, "%s\n", _name.utf8().data() );
-    fprintf( fptr, "%s\n", _archiveName.utf8().data() );
-    fprintf( fptr, "%s\n", _workingDirectory.utf8().data() );
+    fprintf( fptr, "%s\n", _name.toUtf8().data() );
+    fprintf( fptr, "%s\n", _archiveName.toUtf8().data() );
+    fprintf( fptr, "%s\n", _workingDirectory.toUtf8().data() );
     fprintf( fptr, "%d\n", _absoluteFiles.count() );
     for ( QStringList::Iterator it = _absoluteFiles.begin();
           it != _absoluteFiles.end();
           ++it )
-        fprintf( fptr, "%s\n", (*it).utf8().data() );
+        fprintf( fptr, "%s\n", (*it).toUtf8().data() );
     fprintf( fptr, "%d\n", _oneFilesystem );
     fprintf( fptr, "%d\n", _incremental );
-    fprintf( fptr, "%s\n", _snapshotFile.utf8().data() );
+    fprintf( fptr, "%s\n", _snapshotFile.toUtf8().data() );
     fprintf( fptr, "%d\n", _removeSnapshot );
 
     fclose( fptr );
@@ -195,10 +195,10 @@ bool BackupProfile::getRemoveSnapshot()
 void BackupProfile::setName( const QString & name )
 {
     _name = name;
-    
+
     BackupProfileManager::instance()->backupProfileModified( this );
 }
-    
+
 void BackupProfile::setArchiveName( const QString & archiveName )
 {
     _archiveName = archiveName;
@@ -212,7 +212,7 @@ void BackupProfile::setWorkingDirectory( const QString & workingDirectory )
 
     // Regenerate the list of relative files.
     calcRelativeFiles();
-    
+
     BackupProfileManager::instance()->backupProfileModified( this );
 }
 
@@ -239,7 +239,7 @@ void BackupProfile::setAbsoluteFiles( const QStringList& files )
 
     // Regenerate the list of relative files.
     calcRelativeFiles();
-    
+
     BackupProfileManager::instance()->backupProfileModified( this );
 }
 
