@@ -20,11 +20,13 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include <qdir.h>
+#include <QDir>
 #include <qpainter.h>
 #include <qstyle.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <Q3PtrList>
 
-#include <kapplication.h>
 #include <kdebug.h>
 
 #include "Archive.h"
@@ -160,7 +162,7 @@ bool TapeNode::validate()
     }
 
     // Add/update existing archives.
-    QPtrListIterator<Archive> i( _tape->getChildren() );
+    Q3PtrListIterator<Archive> i( _tape->getChildren() );
     ArchiveNode* n;
     for ( ; i.current(); ++i ) {
         n = findArchiveNode( i.current() );
@@ -215,7 +217,7 @@ void TapeNode::expanding( bool expand )
         return;
     }
 
-    QPtrListIterator<Archive> f( _tape->getChildren() );
+    Q3PtrListIterator<Archive> f( _tape->getChildren() );
     for ( ; f.current(); ++f ) {
         insertNode( new ArchiveNode( f.current() ) );
     }
@@ -284,7 +286,7 @@ void ArchiveNode::expanding( bool expand )
         return;
     }
 
-    QPtrListIterator<File> f( _archive->getChildren() );
+    Q3PtrListIterator<File> f( _archive->getChildren() );
     for ( ; f.current(); ++f ) {
         if ( f.current()->getName()[f.current()->getName().length()-1] == '/' ) {
             insertNode( new TapeDirectoryNode( f.current() ) );
@@ -311,7 +313,7 @@ TapeDirectoryNode::TapeDirectoryNode( File* file )
     setDelayedExpanding( TRUE );
 
     int len  = _file->getName().length();
-    int idx1 = _file->getName().findRev( '/', len - 2 );
+    int idx1 = _file->getName().lastIndexOf( '/', len - 2 );
     if ( idx1 < 0 ) {
         setText( _file->getName().left( len - 1 ) );
     } else {
@@ -342,7 +344,7 @@ void TapeDirectoryNode::expanding( bool expand )
         return;
     }
 
-    QPtrListIterator<File> f( _file->getChildren() );
+    Q3PtrListIterator<File> f( _file->getChildren() );
     for ( ; f.current(); ++f ) {
         if ( f.current()->getName()[f.current()->getName().length()-1] == '/' ) {
             insertNode( new TapeDirectoryNode( f.current() ) );
@@ -372,7 +374,7 @@ TapeFileNode::TapeFileNode( File* file )
           _file( file )
 {
     int len  = _file->getName().length();
-    int idx1 = _file->getName().findRev( '/', len - 1 );
+    int idx1 = _file->getName().lastIndexOf( '/', len - 1 );
     if ( idx1 < 0 ) {
         setText( _file->getName().left( len ) );
     } else {
@@ -548,8 +550,13 @@ void SelectableNode::paintText( QPainter* p, int indent, int cellHeight,
     int textY = cellHeight - ((cellHeight - p->fontMetrics().ascent() -
 			       p->fontMetrics().leading()) / 2);
     if (highlighted) {
-	paintHighlight(p, indent, cg, owner->hasFocus(),
-                (Qt::GUIStyle)owner->style().styleHint(QStyle::SH_GUIStyle)); // Qt3 doesn't make this easy ;)
+        QStyle *style = owner->style(); 
+	Qt::GUIStyle sty;
+	// FIXME
+	//.styleHint(QStyle::SH_GUIStyle)); // Qt3 doesn't make this easy ;)
+	style->styleHint ( QStyle::SH_GUIStyle );
+	paintHighlight(p, indent, cg, owner->hasFocus(), sty);
+	//FIXME (Qt::GUIStyle)owner->style().styleHint(QStyle::SH_GUIStyle)); // Qt3 doesn't make this easy ;)
 	p->setPen(cg.base());
 	p->setBackgroundColor(cg.text());
     }
@@ -636,7 +643,7 @@ Archive* MountedArchiveNode::getArchive()
     return _archive;
 }
 
-const QPtrList<Range>& MountedArchiveNode::getRanges()
+const Q3PtrList<Range>& MountedArchiveNode::getRanges()
 {
     return _archive->getRanges();
 }
@@ -684,7 +691,7 @@ void MountedArchiveNode::expanding( bool expand )
         return;
     }
 
-    QPtrListIterator<File> f( _archive->getChildren() );
+    Q3PtrListIterator<File> f( _archive->getChildren() );
     for ( ; f.current(); ++f ) {
         if ( f.current()->getName()[f.current()->getName().length()-1] == '/' ) {
             insertNode( new MountedTapeDirectoryNode( f.current(), _state == SelSome ? SelNone : _state ) );
@@ -713,7 +720,7 @@ MountedTapeDirectoryNode::MountedTapeDirectoryNode( File* file, int state )
     setDelayedExpanding( TRUE );
 
     int len  = _file->getName().length();
-    int idx1 = _file->getName().findRev( '/', len - 2 );
+    int idx1 = _file->getName().lastIndexOf( '/', len - 2 );
     if ( idx1 < 0 ) {
         setText( _file->getName().left( len - 1 ) );
     } else {
@@ -739,7 +746,7 @@ QString MountedTapeDirectoryNode::getFullPath()
     return _fullPath;
 }
 
-const QPtrList<Range>& MountedTapeDirectoryNode::getRanges()
+const Q3PtrList<Range>& MountedTapeDirectoryNode::getRanges()
 {
     return _file->getRanges();
 }
@@ -784,7 +791,7 @@ void MountedTapeDirectoryNode::expanding( bool expand )
         return;
     }
 
-    QPtrListIterator<File> f( _file->getChildren() );
+    Q3PtrListIterator<File> f( _file->getChildren() );
     for ( ; f.current(); ++f ) {
         if ( f.current()->getName()[f.current()->getName().length()-1] == '/' ) {
             insertNode( new MountedTapeDirectoryNode( f.current(), _state == SelSome ? SelNone : _state ) );
@@ -819,7 +826,7 @@ MountedTapeFileNode::MountedTapeFileNode( File* file, int state )
           _file( file )
 {
     int len  = _file->getName().length();
-    int idx1 = _file->getName().findRev( '/', len - 1 );
+    int idx1 = _file->getName().lastIndexOf( '/', len - 1 );
     if ( idx1 < 0 ) {
         setText( _file->getName().left( len ) );
     } else {
@@ -845,7 +852,7 @@ QString MountedTapeFileNode::getFullPath()
     return _fullPath;
 }
 
-const QPtrList<Range>& MountedTapeFileNode::getRanges()
+const Q3PtrList<Range>& MountedTapeFileNode::getRanges()
 {
     return _file->getRanges();
 }
@@ -976,15 +983,16 @@ void RootNode::expanding( bool expand )
         }
 
         // Fill in the child's children.
-        const QFileInfoList* list = dir.entryInfoList( QDir::Hidden | QDir::Files | QDir::Dirs, QDir::Name | QDir::DirsFirst );
-        if ( list ) {
-            QFileInfoListIterator it( *list );
-            for ( ; it.current(); ++it ) {
-                if ( ( it.current()->fileName() != "." ) && ( it.current()->fileName() != ".." ) ) {
-                    if ( it.current()->isDir() ) {
-                        appendChild( new DirectoryNode( it.current()->fileName(), _state == SelSome ? SelNone : _state ) );
+        QList<QFileInfo> list = dir.entryInfoList( QDir::Hidden | QDir::Files | QDir::Dirs, QDir::Name | QDir::DirsFirst );
+        if ( ! list.isEmpty() ) {
+            QListIterator<QFileInfo> it( list );
+	    while ( it.hasNext() ) {
+                QFileInfo finfo = it.next();
+                if ( ( finfo.fileName() != "." ) && ( finfo.fileName() != ".." ) ) {
+                    if ( finfo.isDir() ) {
+                        appendChild( new DirectoryNode( finfo.fileName(), _state == SelSome ? SelNone : _state ) );
                     } else {
-                        appendChild( new FileNode( it.current()->fileName(), _state == SelSome ? SelNone : _state ) );
+                        appendChild( new FileNode( finfo.fileName(), _state == SelSome ? SelNone : _state ) );
                     }
                 }
             }
@@ -1054,7 +1062,7 @@ void DirectoryNode::expanding( bool expand )
     if ( childCount() > 0 ) {
         struct stat statinfo;
         if ( stat( QFile::encodeName(path), &statinfo ) < 0 ) {
-            kdError() << "Can't stat " << path << endl;
+            kError() << "Can't stat " << path << endl;
             expand = FALSE;
             return;
         }
@@ -1075,7 +1083,7 @@ void DirectoryNode::expanding( bool expand )
     } else {
         struct stat statinfo;
         if ( stat( QFile::encodeName(path), &statinfo ) < 0 ) {
-            kdError() << "Can't stat " << path << endl;
+            kError() << "Can't stat " << path << endl;
             expand = FALSE;
             return;
         }
@@ -1092,15 +1100,16 @@ void DirectoryNode::expanding( bool expand )
         }
 
         // Fill in the child's children.
-        const QFileInfoList* list = dir.entryInfoList( QDir::Hidden | QDir::Files | QDir::Dirs, QDir::Name | QDir::DirsFirst );
-        if ( list ) {
-            QFileInfoListIterator it( *list );
-            for ( ; it.current(); ++it ) {
-                if ( ( it.current()->fileName() != "." ) && ( it.current()->fileName() != ".." ) ) {
-                    if ( it.current()->isDir() ) {
-                        appendChild( new DirectoryNode( it.current()->fileName(), _state == SelSome ? SelNone : _state ) );
+        QList<QFileInfo> list = dir.entryInfoList( QDir::Hidden | QDir::Files | QDir::Dirs, QDir::Name | QDir::DirsFirst );
+        if ( ! list.isEmpty() ) {
+            QListIterator<QFileInfo> it( list );
+	    while ( it.hasNext() ) {
+		QFileInfo finfo = it.next();
+                if ( ( finfo.fileName() != "." ) && ( finfo.fileName() != ".." ) ) {
+                    if ( finfo.isDir() ) {
+                        appendChild( new DirectoryNode( finfo.fileName(), _state == SelSome ? SelNone : _state ) );
                     } else {
-                        appendChild( new FileNode( it.current()->fileName(), _state == SelSome ? SelNone : _state ) );
+                        appendChild( new FileNode( finfo.fileName(), _state == SelSome ? SelNone : _state ) );
                     }
                 }
             }
@@ -1214,7 +1223,7 @@ void TapeDriveNode::expanding( bool expand )
         return;
     }
 
-    QPtrListIterator<Archive> f( TapeManager::instance()->getMountedTape()->getChildren() );
+    Q3PtrListIterator<Archive> f( TapeManager::instance()->getMountedTape()->getChildren() );
     for ( ; f.current(); ++f ) {
         insertNode( new MountedArchiveNode( f.current() ) );
     }
@@ -1283,7 +1292,7 @@ void TapeDriveNode::slotTapeModified( Tape* tape )
     }
 
     // Add/update existing archives.
-    QPtrListIterator<Archive> i( tape->getChildren() );
+    Q3PtrListIterator<Archive> i( tape->getChildren() );
     MountedArchiveNode* n;
     for ( ; i.current(); ++i ) {
         n = findArchiveNode( i.current() );
