@@ -1,4 +1,4 @@
-// $Id: OptionsDlg.cpp 465369 2005-09-29 14:33:08Z mueller $
+// $Id: OptionsDlg.cpp 622348 2007-01-11 16:52:13Z mlaurent $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -24,12 +24,11 @@
 #include "OptionsDlg.h"
 #include "OptionsDlgWidget.h"
 
-#include <qcheckbox.h>
+#include <QCheckBox>
 
 #include <kcombobox.h>
 #include <klineedit.h>
 #include <knuminput.h>
-#include <kapplication.h>
 #include <klocale.h>
 #include <kglobal.h>
 
