@@ -1,7 +1,4 @@
 /*
- * $Revision: 1.11 $
- * $Date: 2003/03/07 22:05:55 $
- * 
  * KTreeView class interface
  * 
  * Copyright (C) 1997 Johannes Sixt
@@ -19,7 +16,7 @@
  * MERCHANTABLILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details. You should have received a copy
  * of the GNU General Public License along with this program; if not, write
- * to the Free Software Foundation, Inc, 59 Temple Place - Suite 330, Boston, MA  02111-1307,
+ * to the Free Software Foundation, Inc, 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
  * USA.
  */
 
@@ -27,12 +24,15 @@
 #define KDE_KTREE_VIEW_H
 
 #include <qpixmap.h>			/* used in items */
-#include <qptrstack.h>			/* used to specify tree paths */
-#include <qstring.h>			/* used in items */
-#include <qgridview.h>			/* base class for widget */
-
+			/* used in items */
+#include <q3gridview.h>			/* base class for widget */
+//Added by qt3to4:
+#include <QMouseEvent>
+#include <QFocusEvent>
+#include <QKeyEvent>
+#include <QStack>
 // use stack of strings to represent path information
-typedef QPtrStack<QString> KPath;
+typedef QStack<QString *> KPath;
 
 class KTreeView;			/* forward declaration */
 
@@ -398,7 +398,7 @@ typedef bool (*KForEvery)
   signal void collpased(int) - emitted when an item in the tree is collapsed;
   sends the index of the item
   */
-class KTreeView : public QGridView
+class KTreeView : public Q3GridView
 {
     friend class KTreeViewItem;
     Q_OBJECT
@@ -409,7 +409,7 @@ public:
      * current item to -1, and sets default values for scroll bars (both
      * auto).
      */
-    KTreeView(QWidget* parent = 0, const char* name = 0, WFlags f = 0);
+    KTreeView(QWidget* parent = 0, const char* name = 0, Qt::WFlags f = 0);
 
     /*
      * Desctructor. Deletes all items from the topmost level that have been
