@@ -33,7 +33,7 @@ bool KAddressValidator::isValidIPAddress(QString addr){
   int i;
   int number;
   bool ok;
-  if ((addr.contains('.') > 3) || (addr.length() > 15))
+  if ((addr.count('.') > 3) || (addr.length() > 15))
     return false;
   for (i = 0; i < 4; i++)
   {
@@ -188,13 +188,11 @@ QString KAddressValidator::calculateNetwork(QString addr,QString netmask){
   struct in_addr _addr, _netmask, _network;
   int prefix = 0;
   QString s;  
-  if (addr.isNull() || netmask.isNull())
-    return NULL; //bad address
-  if (!inet_pton(AF_INET,addr.latin1(),&_addr))
+  if (!inet_pton(AF_INET,addr.toLatin1(),&_addr))
     return NULL; //bad address
   else
   {
-    if (!inet_pton(AF_INET,netmask.latin1(),&_netmask))
+    if (!inet_pton(AF_INET,netmask.toLatin1(),&_netmask))
       return NULL; //bad address
     else
     {
@@ -216,13 +214,11 @@ QString KAddressValidator::calculateBroadcast(QString addr, QString netmask){
   struct in_addr _addr, _netmask, _network;
   int prefix = 0;
   QString s;
-  if (addr.isNull() || netmask.isNull())
-    return NULL; //bad address
-  if (!inet_pton(AF_INET,addr.latin1(),&_addr))
+  if (!inet_pton(AF_INET,addr.toLatin1(),&_addr))
     return NULL; //bad address
   else
   {
-    if (!inet_pton(AF_INET,netmask.latin1(),&_netmask))
+    if (!inet_pton(AF_INET,netmask.toLatin1(),&_netmask))
       return NULL; //bad address
     else
     {
