@@ -25,32 +25,33 @@
 */
 
 
-#include "../config.h"
+#include <QtCore/QTimer>
+#include <QtCore/QRegExp>
+//Added by qt3to4:
+#include <QtCore/QTextCodec>
 
-#include <qtimer.h>
-#include <qregexp.h> 
-
-#include <kprocctrl.h>
+#include <k3processcontroller.h>
 #include <kpty.h>
 #include <kdebug.h>
-#include <kpassdlg.h>
+#include <kpassworddialog.h>
+#include <kapplication.h>
 
 #include <kpPty.h>
 #include <kpackage.h>
 #include <kpTerm.h>
-#include <options.h>
+#include <kpSettings.h>
+#include <kpackageSettings.h>
 #include <utils.h>
 
 #define SHPROMPT "# "
-const int TIMEOUT = -3;
-const int PASSWORD = -2;
-const int PROMPT = -1;
+const int TIMEOUT = -33;
+const int PASSWORD = -2000;
+const int PROMPT = -1000;
 
-extern Opts *opts;
 //////////////////////////////////////////////////////////////////////////////
 
 kpKProcIO::kpKProcIO ( QTextCodec *_codec)
-  : KProcIO(_codec)
+  : K3ProcIO(_codec)
 {
 }
 
@@ -61,38 +62,39 @@ kpKProcIO::~kpKProcIO()
 bool kpKProcIO::sstart (RunMode runmode)
 {
 
-  connect (this, SIGNAL (receivedStdout (KProcess *, char *, int)),
-	   this, SLOT (received (KProcess *, char *, int)));
+  connect (this, SIGNAL (receivedStdout (K3Process *, char *, int)),
+	   this, SLOT (received (K3Process *, char *, int)));
 
 
-  connect (this, SIGNAL (wroteStdin(KProcess *)),
-	   this, SLOT (sent (KProcess *)));
+  connect (this, SIGNAL (wroteStdin(K3Process *)),
+	   this, SLOT (sent (K3Process *)));
 
-  return KProcess::start (runmode,( KProcess::Communication) ( KProcess::Stdin |  KProcess::Stdout));
+  return K3Process::start (runmode,( K3Process::Communication) ( K3Process::Stdin |  K3Process::Stdout));
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 kpPty::kpPty() : QObject()
 {
-  pty = new kpKProcIO();
-  pty->setUsePty(KProcess::All, false);
+  QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+  pty = new kpKProcIO(codec);
+  pty->setUsePty(K3Process::All, false);
 
-  connect(pty, SIGNAL(readReady(KProcIO *)), this,
+
+  connect(pty, SIGNAL(readReady(K3ProcIO *)), this,
 		   SLOT(readLines()));
-  connect(pty, SIGNAL(processExited(KProcess *)), this,
+  connect(pty, SIGNAL(processExited(K3Process *)), this,
 		   SLOT(done()));
   pty->pty()->setWinSize(0,80);
   tm = new QTimer(this);
   connect(tm, SIGNAL(timeout()), this, SLOT(slotTimeout()));
 
-  eventLoop = FALSE;
-  inSession = FALSE;
-  pUnterm = FALSE;
-  loginSession = FALSE;
+  eventLoop = false;
+  inSession = false;
+  pUnterm = false;
+  loginSession = false;
   
   codec = QTextCodec::codecForLocale();
-  QMap<QString, QCString> passwords;
 }
 
 
@@ -102,21 +104,21 @@ kpPty::~kpPty()
 
 void kpPty::startSu()
 {
-  kdDebug() << "startSu()\n";
+  kDebug() << "startSu()\n";
   pty->setEnvironment("PS1", SHPROMPT);
   (*pty) << "su" << "-s" << "/bin/sh";
 }
 
 void kpPty::startSudo()
 {
-  kdDebug() << "startSudo()\n";
+  kDebug() << "startSudo()\n";
   pty->setEnvironment("PS1", SHPROMPT);
   (*pty) << "sudo" << "-p" << "Password: " << "/bin/sh";
 }
 
 void kpPty::startSsh()
 {
-  kdDebug() << "startSsh()\n";
+  kDebug() << "startSsh()\n";
   (*pty) << "/usr/bin/ssh" << "-t" << "-l" << "root";
   if (hostName.isEmpty()) {
     (*pty) << "-o" << "StrictHostKeyChecking=no" << "localhost";
@@ -133,106 +135,110 @@ bool kpPty::needSession(bool needRoot)
 
 bool kpPty::startSession(bool needRoot)
 {
-  bool interact = FALSE; // Have interacted with user, prevents loops
-  bool passwordTried = FALSE; // Have tried the current save password, so need to put up dialog
-  pUnterm = FALSE;
-  kdDebug() << "kpPty::startSession\n";
+  bool interact = false; // Have interacted with user, prevents loops
+  bool passwordTried = false; // Have tried the current save password, so need to put up dialog
+  pUnterm = false;
+  kDebug() << "kpPty::startSession\n";
   if (!inSession && needSession(needRoot)) {
     // Assume !needRoot actions are simple executables
-    kdDebug() << "kpPty::startSession TRUE\n";
-    loginSession = TRUE;
+    kDebug() << "kpPty::startSession TRUE\n";
+    loginSession = true;
     int ret;
     QString s = "echo START=$?\n";
 
   FULL_RESTART:
-    interact = FALSE;
+    interact = false;
     retList.clear();
     pty->resetAll();
 
     QString passMsg;
-    kdDebug() << "privCmd=" << opts->privCmd << "\n";
-    if (opts->privCmd == Opts::SSHcmd || !hostName.isEmpty()) {
+    kDebug() << "privCmd=" << kpkg->conf->privCommand << " " << Settings::EnumPrivCommand::sudo << " " << Settings::EnumPrivCommand::su << "\n";
+    if (kpkg->conf->privCommand == Settings::EnumPrivCommand::ssh || !hostName.isEmpty()) {
       passMsg = i18n("The action you requested uses ssh. Please enter the password or pass phrase.\n");
       startSsh();
-    } else if (opts->privCmd == Opts::SUcmd) {
+    } else if (kpkg->conf->privCommand == Settings::EnumPrivCommand::su) {
       passMsg = i18n("The action you requested needs root privileges. Please enter root's password.\n");
       startSu();
-    } else if (opts->privCmd == Opts::SUDOcmd) {
-      passMsg = i18n("The action you requested needs root privileges. Please enter your SUDO password.\n");
+    } else if (kpkg->conf->privCommand == Settings::EnumPrivCommand::sudo) {
+      passMsg = i18n("The action you requested needs root privileges. Please enter your password.\n");
       startSudo();
+    } else {
+      kDebug() << "privCommand Invalid\n";
     }
-    pty->sstart(KProcess::NotifyOnExit);
+    pty->sstart(K3Process::NotifyOnExit);
 
   RESTART:
-    tm->start(6*1000, TRUE);
-    eventLoop = TRUE;
-    kdDebug() << "Loopst\n";
+    tm->start(6*1000);
+    eventLoop = true;
+    kDebug() << "Loopst\n";
     kapp->enter_loop();
-    kdDebug() << "Loopfn Result=" << Result  <<  "\n";
+    kDebug() << "Loopfn Result=" << Result  <<  "\n";
     tm->stop();
     if (Result == TIMEOUT) { // timeout
-      interact = TRUE;
-      //      kdDebug() << "Line=" << retList.last() << "\n";
+      interact = true;
+      //      kDebug() << "Line=" << retList.last() << "\n";
       kpstart->addText(retList);
       kpstart->run("", i18n("Login Problem: Please login manually"));
 
       ret = kpstart->exec();
-      kdDebug() << "Sret=" << ret << "\n";
+      kDebug() << "Sret=" << ret << "\n";
       if (ret) {
-	inSession = FALSE;
+	inSession = false;
       } else {
-	inSession = TRUE;
+	inSession = true;
       }
     } else if (Result == PASSWORD) {  // We got a password prompt
-      QCString pass;
+      QString pass;
       int res;
-      interact = TRUE;
-      // kdDebug() << "H=" << hostName << " PH=" << passwords[hostName] << " PT=" << passwordTried <<"\n";
-      if (passwords[hostName] != 0 && !passwordTried) {
+      interact = true;
+      kDebug() << "H=" << hostName << " PT=" << passwordTried <<"\n";
+
+	  if (passwords[hostName].count()!=0 && !passwordTried) {
         pass = passwords[hostName];
         res = 1;
       } else {
-        kdDebug() << "Passwd=" << retList.last() << "\n";
+        kDebug() << "Passwd=" << retList.last() << "\n";
         QString msg = passMsg;
-        //        kdDebug() << "privCmd=" << opts->privCmd << " host=" << hostName.isEmpty() << "\n";
-        if (opts->privCmd == Opts::SSHcmd || !hostName.isEmpty()) {
+	if (kpkg->conf->privCommand == Settings::EnumPrivCommand::ssh || !hostName.isEmpty()) {
           msg += retList.last();
         }
-        int keep = 1;
-        res = KPasswordDialog::getPassword(pass,msg,&keep);
-        //     kdDebug() << "Pass=" << pass << " Keep=" << keep << " Res=" << res << "\n";
-        if (keep) {
+        KPasswordDialog dlg(0 , KPasswordDialog::ShowKeepPassword);
+        dlg.setPrompt( msg );
+        res = dlg.exec();
+        pass = dlg.password();
+//            kDebug() << "Pass=" << pass <<  " Res=" << res << "\n";
+        if (res && dlg.keepPassword()) {
           passwords[hostName] = pass;
-        } else {
+        } else if(res) {
           passwords.remove(hostName);
         }
       }
       pty->writeStdin(pass.append("\n"), false);
-      passwordTried = TRUE;
+      passwordTried = true;
       if (res) {
         retList.clear();
         goto RESTART;
       } else {
-        inSession = FALSE;
+        inSession = false;
       }
     } else if (Result == PROMPT) { // Got Prompt
-      inSession = TRUE;
-      kdDebug() << "kpPty::startSession TRUE\n";
+      inSession = true;
+      kDebug() << "kpPty::startSession TRUE\n";
     } else {  // process return code
-      pty->writeStdin(QCString("\04"), false);  // SU doesn't listen to ^C
+      pty->writeStdin(QByteArray("\04"), false);  // SU doesn't listen to ^C
       if (interact) {
 	goto FULL_RESTART;
       } else {
 	QString errMsg = retList.join(" ");
-	KpMsgE(errMsg, TRUE);
-        inSession = FALSE;
+	KpMsgE(errMsg, true);
+        inSession = false;
       }
     }
   } else {
-    kdDebug() << "kpPty::startSession Not needed\n";
+    kDebug() << "kpPty::startSession Not needed\n";
   }
   
-  loginSession = FALSE;
+  loginSession = false;
   if (!inSession)
     close();
   
@@ -241,157 +247,168 @@ bool kpPty::startSession(bool needRoot)
 
 void kpPty::breakUpCmd(const QString &cmd)
 {
-  kdDebug() << " kpPty::run CMD=\""<< cmd <<"\" pty = " << pty << endl;
+  kDebug() << " kpPty::run CMD=\""<< cmd <<"\" pty = " << pty << "\n";
 
-  bool quote = FALSE;
+  bool quote = false;
   QString s;
-  QStringList cl = QStringList::split(" ", cmd);
+  QStringList cl = cmd.split(" ", QString::SkipEmptyParts);
 
   for ( QStringList::Iterator it = cl.begin(); it != cl.end(); ++it ) {
+//    kDebug() << "S=" << *it << "\n";
     int lastPt = (*it).length() - 1;
     if ((*it)[0] == '\'') { // Start of quoted string
       s = *it;
       if ((*it)[lastPt] == '\'') { // Also End of quoted string
 	s.replace("'","");
 	(*pty) << s;
-	quote = FALSE;
+	quote = false;
       } else {
-	s += " ";
-	quote = TRUE;
+	s += ' ';
+	quote = true;
       }
     } else if ((*it)[lastPt] == '\'') { // End of quoted string
       s += *it;
       s.replace("'","");
       (*pty) << s;
-      quote = FALSE;
+      quote = false;
     }	else if (quote) {
       s += *it;
-      s += " ";
+      s += ' ';
     } else {
       (*pty) << (*it);
     }
   }
 }
 
-QStringList kpPty::run(const QString &cmd, bool inLoop, bool needRoot)
+void kpPty::listClear() 
+{
+  retList.clear();
+}
+
+QStringList kpPty::run(const QString &cmd, bool inLoop, bool needRoot, bool noReturn)
 {
   Result = 0;
 
-  pUnterm = FALSE;
+  pUnterm = false;
+  noRet = noReturn;
 
   if (!inSession && !needSession(needRoot)) {
     // Assume !needRoot actions are simple executables
     pty->resetAll();
     breakUpCmd(cmd);
     pty->setEnvironment("TERM", "dumb");
-    if (!pty->sstart(KProcess::NotifyOnExit)) {
-      kdDebug() << " kpPty::run execute=0\n";
-      return 0;
+    if (!pty->sstart(K3Process::NotifyOnExit)) {
+      kDebug() << " kpPty::run execute=0\n";
+      return QStringList();
     }
   } else {
     if (startSession(needRoot)) {
-      kdDebug() << "CMDroot='"<< cmd <<"'\n";
+      kDebug() << "CMDroot='"<< cmd <<"'\n";
       QString s = cmd + ";echo RESULT=$?";
       pty->writeStdin(s);
-      kdDebug() << " kpPty::run session\n";
+      kDebug() << " kpPty::run session\n";
     } else {
-      kdDebug() << " kpPty::run other=0\n";
-      return 0;
+      kDebug() << " kpPty::run other=0\n";
+      return QStringList();
     }
   }
-
   retList.clear();
 
   if (inLoop) {
-    eventLoop = TRUE;
+    eventLoop = true;
     kapp->enter_loop();
-
+    kDebug() << "return Result=" << Result << " " << retList.count() << "\n";
     return retList;
   } else {
-    return 0;
+    return QStringList();
   }
 }
 
 void kpPty::close() {
-  //  kdDebug() << "kpPty::close\n";
+  //  kDebug() << "kpPty::close\n";
 
   pty->closeAll();
   while(pty->isRunning()) {
-    KProcessController::theKProcessController->waitForProcessExit(1);
+    K3ProcessController::instance()->waitForProcessExit(1);
   }
   inSession = false;
 }
 
 void kpPty::finish(int ret)
 {
-   kdDebug() << "kpPty::finish " << ret << "\n";
+//   kDebug() << "kpPty::finish " << ret << " " << retList.count() << "\n";
 
   QStringList::Iterator l;
-  Result = ret;
 
   if (ret == PROMPT) {  // Called program executed in session
-    if (!retList.empty()) {
+   if (!retList.empty()) {
       l = retList.fromLast();
       if ((*l).right(2) == SHPROMPT) {
-	retList.remove(l);                  // Remove prompt
+	retList.erase(l);                  // Remove prompt
       }
     }
 
     if (!retList.empty()) {
       int p;
       l = retList.fromLast();
-      if ((p = (*l).find("RESULT=")) >= 0) {
+//      kDebug() << "kpPty::finish RESULT=" << *l << "\n";
+      if ((p = (*l).indexOf("RESULT=")) >= 0) {
 	ret = (*l).mid(p+7).toInt(0,10);
-	retList.remove(l);                  // Remove return code
-      } else {
-	ret = 666;
-      }
+	retList.erase(l);                  // Remove return code
+      } 
     }
 
     if (!retList.empty()) {
       l = retList.begin();
       if ( l !=  retList.end()) {
-	if ((*l).find("RESULT=") >= 0) {
-	  retList.remove(l);                  // Remove command at start
+	if ((*l).indexOf("RESULT=") >= 0) {
+	  retList.erase(l);                  // Remove command at start
 	}
       }
     }
   } 
   emit result(retList,ret);
  
+//  kDebug() << "Result=" << Result << " ret=" << ret <<"\n";
+  Result = ret;   
 
   if (eventLoop) {
-    eventLoop = FALSE;
+    eventLoop = false;
     kapp->exit_loop();
   }
 }
 
 void kpPty::readLines()
 {
-  bool unterm = FALSE;
+  bool unterm = false;
 
   QString stext;
   while(pty->readln(stext, false, &unterm) >= 0)
   {
-    stext = codec->toUnicode(stext.ascii(), stext.length());
+   //         kDebug() << "[=" << pUnterm << "-" << unterm << "=" << stext.length() << "-" << stext << ">\n";
+    
     emit textIn(stext, !unterm);
-//              kdDebug() << "[" << pUnterm << "-" << unterm << "-" << stext << ">\n";
+   
     if (pUnterm) {
-      QStringList::Iterator lst = retList.fromLast();
+      QStringList::Iterator lst;
+      lst = retList.fromLast();
       if (lst != retList.end())
       {
         stext = *lst + stext;
-        retList.remove(lst);
+        retList.erase(lst);
       }
-    }
+    } 
+    
+    if (!unterm) 
+	emit textLine(stext);
+    
     int i;
-    if (!unterm)
-    {
+    if (!unterm) {
       while (stext.endsWith("\r")) {
           stext.truncate(stext.length()-1);
       }
        
-      i = stext.findRev('\r');
+      i = stext.lastIndexOf('\r');
       if (i > -1) {
         stext = stext.mid(i+1);
       }
@@ -399,15 +416,17 @@ void kpPty::readLines()
 
     pUnterm = unterm;
 
-    retList << stext;
- //   kdDebug() << "++" << stext << "\n";
+    if (!noRet || unterm)
+      retList << stext;
+    
+ //   kDebug() << "++" << stext << "\n";
     if (stext.right(2) == SHPROMPT) {  // Shell prompt
       emit textIn("\r \n", false);
       finish(PROMPT);
     } else if (loginSession)  {
       QRegExp rx( "^[^:]+:[\\s]*$");  // Password prompt
-      if (rx.search(retList.last()) >= 0) {
-        kdDebug() << loginSession << " " <<retList.last()<< " Match password p\n";
+      if (rx.indexIn(retList.last()) >= 0) {
+        kDebug() << loginSession << " " <<retList.last()<< " Match password p\n";
 	finish(PASSWORD);
       }
     }
@@ -415,12 +434,9 @@ void kpPty::readLines()
   pty->ackRead();
 }
 
-void kpPty::keyOut(char ch)
+void kpPty::keyOut(QString s)
 {
-  QCString s(2);
-  s[0] = ch;
-  s[1] = '\0';
-  pty->writeStdin(s, false);
+ pty->writeStdin(s, false);
 }
 
 void kpPty::done()
@@ -428,14 +444,12 @@ void kpPty::done()
   int ret = pty->exitStatus();
   QString stext;
 
-  //kdDebug() << "Done (" << ret << ")" << endl;
-
   finish(ret);
 }
 
 void kpPty::slotTimeout()
 {
-  kdDebug() << "Timeout..............\n";
+  kDebug() << "Timeout..............\n";
   finish(TIMEOUT);
 }
 #include "kpPty.moc"
