@@ -28,28 +28,33 @@
 
 #include <ctype.h>
 
-#include <qpopupmenu.h>
-#include <qkeycode.h>
+#include <q3popupmenu.h>
+#include <qnamespace.h>
 #include <qmessagebox.h>
 #include <qfontmetrics.h>
 #include <qpainter.h>
-#include <qmultilineedit.h>
+#include <q3multilineedit.h>
 #include <qdatetime.h>
-#include <kprinter.h>
-#include <qpaintdevicemetrics.h>
-#include <qbuttongroup.h>
+//Added by qt3to4:
+#include <QCloseEvent>
+#include <Q3ValueList>
+#include <q3paintdevicemetrics.h>
+#include <q3buttongroup.h>
 #include <qclipboard.h>
-#include <qtooltip.h>
-#include <qcheckbox.h>
-#include <qhbox.h>
-#include <qregexp.h>
-#include <qdatastream.h>
+
+#include <QCheckBox>
+#include <q3hbox.h>
+#include <QRegExp>
+#include <QDataStream>
 #include <qpixmapcache.h>
-#include <qtextview.h>
+#include <q3textview.h>
 #include <qfileinfo.h>
 #include <qtextstream.h>
-#include <qwhatsthis.h>
-#include <qsimplerichtext.h>
+
+#include <QtGui/QPrinter>
+#include <QtGui/QPrintDialog>
+
+#include <q3simplerichtext.h>
 
 #include <kresolver.h>
 #include <ktoolbar.h>
@@ -57,19 +62,19 @@
 #include <kmenubar.h>
 #include <kcompletion.h>
 #include <kaction.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <kdebug.h>
-#include <kapplication.h>
 #include <kglobal.h>
 #include <khelpmenu.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kstdaccel.h>
+#include <kstandardshortcut.h>
 #include <kedittoolbar.h>
 #include <kiconloader.h>
 #include <kfiledialog.h>
 #include <kaboutdata.h>
 #include <kcursor.h>
+#include <kdeprintdialog.h>
 
 #include "kbusymanager.h"
 #include "ServiceDlg.h"
@@ -84,7 +89,7 @@
 #include "OldView.h"
 #include "IOCore.h"
 #include "TopWidget.h"
-#include <qlabel.h>
+#include <QLabel>
 #include <kstatusbar.h>
 
 namespace Status
@@ -95,7 +100,7 @@ namespace Status
 } // namespace Status
 
 KSVTopLevel::KSVTopLevel()
-  : KMainWindow(0, 0L, WStyle_ContextHelp|WDestructiveClose),
+  : KMainWindow(0, 0L, Qt::WStyle_ContextHelp|Qt::WDestructiveClose),
     mConfig(KSVConfig::self()),
 	mView (0L),
     mPreferences (0L),
@@ -158,7 +163,7 @@ KSVTopLevel::KSVTopLevel()
   connect (mRedoList, SIGNAL(filled()), this, SLOT(enableRedo()));
 
   // paste
-  connect (kapp->clipboard(), SIGNAL (dataChanged()),
+  connect (QApplication::clipboard(), SIGNAL (dataChanged()),
 		   this, SLOT (dispatchEdit()));
 
   // init mView according to saved preferences
@@ -211,40 +216,40 @@ void KSVTopLevel::initActions ()
   KActionCollection* coll = actionCollection();
 
   // setup File menu
-  mFileRevert = KStdAction::revert (this, SLOT (slotClearChanges()), coll);
+  mFileRevert = KStandardAction::revert (this, SLOT (slotClearChanges()), coll);
   mFileRevert->setText (i18n("Re&vert Configuration"));
 
-  mFileLoad = KStdAction::open (this, SLOT (load()), coll);
+  mFileLoad = KStandardAction::open (this, SLOT (load()), coll);
   mFileLoad->setText (i18n ("&Open..."));
 
-  mFileSave = KStdAction::save(this, SLOT(slotAcceptChanges()), coll);
+  mFileSave = KStandardAction::save(this, SLOT(slotAcceptChanges()), coll);
   mFileSave->setText (i18n("&Save Configuration"));
 
-  mFileSaveAs = KStdAction::saveAs (this, SLOT (saveAs ()), coll);
+  mFileSaveAs = KStandardAction::saveAs (this, SLOT (saveAs ()), coll);
 
-  mFileSaveLog = KStdAction::save (this, SLOT(slotSaveLog()), coll, "ksysv_save_log");
+  mFileSaveLog = KStandardAction::save (this, SLOT(slotSaveLog()), coll, "ksysv_save_log");
   mFileSaveLog->setText (i18n("Save &Log..."));
-  mFileSaveLog->setShortcut (Key_L+CTRL);
+  mFileSaveLog->setShortcut (QKeySequence(Qt::Key_L+Qt::CTRL));
   mFileSaveLog->setEnabled (false);
 
   // disabled due to complexity
-  //  mFilePrint = KStdAction::print (this, SLOT (print()), coll);
+  //  mFilePrint = KStandardAction::print (this, SLOT (print()), coll);
 
-  mFilePrintLog = KStdAction::print(this, SLOT(printLog()), coll, "ksysv_print_log");
+  mFilePrintLog = KStandardAction::print(this, SLOT(printLog()), coll, "ksysv_print_log");
   mFilePrintLog->setText( i18n("&Print Log..."));
   mFilePrintLog->setEnabled (false);
 
-  mFileQuit = KStdAction::quit(this, SLOT(close()), coll);
+  mFileQuit = KStandardAction::quit(this, SLOT(close()), coll);
 
   // setup Edit menu
-  mEditUndo = KStdAction::undo(this, SLOT(editUndo()), coll);
+  mEditUndo = KStandardAction::undo(this, SLOT(editUndo()), coll);
   mEditUndo->setEnabled (false);
-  mEditRedo = KStdAction::redo(this, SLOT(editRedo()), coll);
+  mEditRedo = KStandardAction::redo(this, SLOT(editRedo()), coll);
   mEditUndo->setEnabled (false);
-  mEditCut = KStdAction::cut(this, SLOT(editCut()), coll);
-  mEditCopy = KStdAction::copy(this, SLOT(editCopy()), coll);
-  mEditPaste = KStdAction::paste(this, SLOT(editPaste()), coll);
-  mPasteAppend = KStdAction::paste (this, SLOT (pasteAppend()),
+  mEditCut = KStandardAction::cut(this, SLOT(editCut()), coll);
+  mEditCopy = KStandardAction::copy(this, SLOT(editCopy()), coll);
+  mEditPaste = KStandardAction::paste(this, SLOT(editPaste()), coll);
+  mPasteAppend = KStandardAction::paste (this, SLOT (pasteAppend()),
 									coll, "ksysv_paste_append");
 
   mEditProperties = new KAction (i18n("P&roperties"), 0,
@@ -260,10 +265,10 @@ void KSVTopLevel::initActions ()
   // setup Settings menu
   createStandardStatusBarAction();
   setStandardToolBarMenuEnabled(true);
-  KStdAction::keyBindings (this, SLOT(configureKeys()), coll);
-  KStdAction::configureToolbars (this, SLOT(configureToolbars()), coll);
-  KStdAction::saveOptions(this, SLOT(saveOptions()), coll);
-  KStdAction::preferences(this, SLOT(slotShowConfig()), coll);
+  KStandardAction::keyBindings (this, SLOT(configureKeys()), coll);
+  KStandardAction::configureToolbars (this, SLOT(configureToolbars()), coll);
+  KStandardAction::saveOptions(this, SLOT(saveOptions()), coll);
+  KStandardAction::preferences(this, SLOT(slotShowConfig()), coll);
   mOptionsToggleLog = new KToggleAction (i18n("Show &Log"), "toggle_log", 0,
 										 this, SLOT (toggleLog()),
 										 coll, "ksysv_toggle_log");
@@ -298,7 +303,7 @@ bool KSVTopLevel::queryExit()
     res = KMessageBox::warningContinueCancel(kapp->mainWidget(),
 				    i18n("There are unsaved changes. Are you sure you want to quit?"),
 				    i18n("Quit"),
-				    KStdGuiItem::quit());
+				    KStandardGuiItem::quit());
 
   }
 
@@ -313,7 +318,7 @@ void KSVTopLevel::slotClearChanges()
 				 i18n("Do you really want to revert all unsaved changes?"),
 				 i18n("Revert Configuration"),
 				 i18n("&Revert"),
-				 KStdGuiItem::cancel()))
+				 KStandardGuiItem::cancel()))
     {
       mUndoList->undoAll();
 	  mRedoList->clear();
@@ -328,7 +333,7 @@ void KSVTopLevel::slotAcceptChanges() {
 				     "make your system hang on startup.\n"
 				     "Do you wish to continue?"),
 				i18n("Save Configuration"),
-				KStdGuiItem::save()))
+				KStandardGuiItem::save()))
     {
       mView->slotWriteSysV();
       initView();
@@ -390,16 +395,16 @@ void KSVTopLevel::initStatusBar()
 {
   KStatusBar* status = statusBar();
 
-  QHBox* visBox = new QHBox (status, "visBox");
-  QButtonGroup* group = new QButtonGroup (this, "visButtonGroup");
+  Q3HBox* visBox = new Q3HBox (status, "visBox");
+  Q3ButtonGroup* group = new Q3ButtonGroup (this, "visButtonGroup");
   group->hide();
   connect (group, SIGNAL (clicked (int)), this, SLOT (toggleRunlevel (int)));
 
-  QWhatsThis::add (visBox, i18n ("<p>Click on the checkboxes to <strong>show</strong> or "\
+  visBox->setWhatsThis( i18n ("<p>Click on the checkboxes to <strong>show</strong> or "\
                                  "<strong>hide</strong> runlevels.</p> " \
                                  "<p>The list of currently visible runlevels is saved "\
                                  "when you use the <strong>Save Options command</strong>.</p>"));
-  QToolTip::add (visBox, i18n ("Show only the selected runlevels"));
+  visBox->setToolTip( i18n ("Show only the selected runlevels"));
 
   new QLabel (i18n("Show runlevels:"), visBox, "visLabel");
   for (int i = 0; i < ksv::runlevelNumber; ++i)
@@ -412,21 +417,21 @@ void KSVTopLevel::initStatusBar()
 	  group->insert (mVisible[i]);
 	}
 
-  QHBox* authIconBox = new QHBox (status, "AuthIconBox");
+  Q3HBox* authIconBox = new Q3HBox (status, "AuthIconBox");
   QWidget* strut = new QWidget (authIconBox, "Strut");
   strut->setFixedWidth (KDialog::spacingHint());
   mAuth = new RunlevelAuthIcon (mConfig->scriptPath(), mConfig->runlevelPath(), authIconBox);
   connect (mAuth, SIGNAL (authChanged(bool)), mView, SLOT(multiplexEnabled(bool)));
   connect (mAuth, SIGNAL (authChanged(bool)), this, SLOT(writingEnabled(bool)));
 
-  QWhatsThis::add (authIconBox, i18n ("<p>If the lock is closed <img src=\"user|ksysv_locked\"/>, "\
+  authIconBox->setWhatsThis( i18n ("<p>If the lock is closed <img src=\"user|ksysv_locked\"/>, "\
                                       "you don't have the right " \
                                       "<strong>permissions</strong> to edit the init configuration.</p>" \
                                       "<p>Either restart %1 as root (or another more privileged user), " \
-                                      "or ask your sysadmin to install %1 <em>suid</em> or " \
+                                      "or ask your sysadmin to install %2 <em>suid</em> or " \
                                       "<em>sgid</em>.</p><p>The latter way is <strong>not</strong> "\
-                                      "recommended though, due to security issues.</p>")
-                   .arg (kapp->aboutData()->programName()).arg(kapp->aboutData()->programName()));
+                                      "recommended though, due to security issues.</p>",
+                     KGlobal::mainComponent().aboutData()->programName(), KGlobal::mainComponent().aboutData()->programName()));
 
   authIconBox->setMinimumSize (authIconBox->minimumSizeHint());
   visBox->setMinimumSize (visBox->minimumSizeHint());
@@ -435,7 +440,7 @@ void KSVTopLevel::initStatusBar()
   status->insertItem ("", Status::Changed, 100);
   status->addWidget (visBox, 0, true);
 
-  status->setItemAlignment (Status::Changed, AlignLeft|AlignVCenter);
+  status->setItemAlignment (Status::Changed, Qt::AlignLeft|Qt::AlignVCenter);
 }
 
 void KSVTopLevel::slotShowConfig()
@@ -508,7 +513,7 @@ void KSVTopLevel::editCut() {
   if (list && list->currentItem())
 	{
 	  KSVDrag* mime = new KSVDrag (*list->currentItem()->data(), 0L, 0L);
-	  kapp->clipboard()->setData (mime);
+	  QApplication::clipboard()->setData (mime);
 
 	  KSVData data = *list->currentItem()->data();
 	  delete list->currentItem();
@@ -525,7 +530,7 @@ void KSVTopLevel::editCopy()
   if (list)
 	{
 	  KSVDrag* mime = new KSVDrag (*static_cast<KSVItem*> (list->currentItem()), 0L, 0L);
-	  kapp->clipboard()->setData (mime);
+	  QApplication::clipboard()->setData (mime);
 	}
 }
 
@@ -537,7 +542,7 @@ void KSVTopLevel::editPaste()
     {
 	  KSVData data;
 
-	  if (KSVDrag::decodeNative (kapp->clipboard()->data(), data))
+	  if (KSVDrag::decodeNative (QApplication::clipboard()->data(), data))
 		{
 		  KSVAction* action = 0L;
 
@@ -563,7 +568,7 @@ void KSVTopLevel::setChanged (bool val)
   mFileSave->setEnabled (val);
 
   // update statusbar
-  statusBar()->changeItem(val ? i18n(" Changed") : QString::null, Status::Changed);
+  statusBar()->changeItem(val ? i18n(" Changed") : QString(), Status::Changed);
 
   // clear messages
   statusBar()->clear();
@@ -628,9 +633,9 @@ void KSVTopLevel::print()
 {
 // #define checkPage if (metrics.height() - y < fm.lineSpacing()) prt.newPage();
 
-//   static KPrinter prt;
-//   prt.setDocName(kapp->aboutData()->programName() + " Configuration");
-//   prt.setCreator(kapp->aboutData()->programName());
+//   static QPrinter prt;
+//   prt.setDocName(KGlobal::mainComponent().aboutData()->programName() + " Configuration");
+//   prt.setCreator(KGlobal::mainComponent().aboutData()->programName());
 
 //   static QPrintDialog* dlg = new QPrintDialog (&prt, this, "KSysV Print Dialog");
 //   dlg->setCaption(kapp->makeStdCaption (i18n("Print")));
@@ -646,9 +651,9 @@ void KSVTopLevel::print()
 //       p.setFont (QFont("courier", 20, QFont::Bold));
 //       QFontMetrics fm = p.fontMetrics();
 
-//       p.drawText (10, y, i18n("%1 Configuration of %2")
-//                   .arg (kapp->aboutData()->programName())
-//                   .arg (ksv::hostname()));
+//       p.drawText (10, y, i18n("%1 Configuration of %2",
+//                   KGlobal::mainComponent().aboutData()->programName(),
+//                   ksv::hostname());
 //       y += fm.lineSpacing();
 
 //       p.drawText (10, y, QDateTime::currentDateTime().toString());
@@ -659,7 +664,7 @@ void KSVTopLevel::print()
 //           p.setFont (QFont("courier", 16, QFont::Bold));
 //           QFontMetrics fm = p.fontMetrics();
 
-//           p.drawText (10, y, i18n ("Runlevel %1").arg(i));
+//           p.drawText (10, y, i18n ("Runlevel %1",i));
 //           y += fm.lineSpacing();
 
 //           checkPage
@@ -746,16 +751,18 @@ void KSVTopLevel::print()
 
 void KSVTopLevel::printLog()
 {
-  KPrinter *prt = new KPrinter();
-  prt->setDocName(kapp->aboutData()->programName() + " Log File");
-  prt->setCreator(kapp->aboutData()->programName());
+  QPrinter *prt = new QPrinter();
+  prt->setDocName(KGlobal::mainComponent().aboutData()->programName() + " Log File");
+  prt->setCreator(KGlobal::mainComponent().aboutData()->programName());
 
-  if (prt->setup(this, i18n("Print Log File")))
+//  if (prt->setup(this, i18n("Print Log File")))
+    QPrintDialog *printDialog = KdePrint::createPrintDialog(prt, parent);
+    if (printDialog->exec())
     {
       KBusyManager::self()->setBusy (true);
 
       QPainter p (prt);
-      QPaintDeviceMetrics pm (prt);
+      Q3PaintDeviceMetrics pm (prt);
       const int height = pm.height();
       const int width = pm.width();
 
@@ -765,9 +772,9 @@ void KSVTopLevel::printLog()
       int y = 0;
 
       {
-        QSimpleRichText rheading (i18n("<h1>KDE Sys-V Init Editor Log</h1>"),
-                                  QFont("times"), QString::null, ksv::styleSheet(),
-                                  QMimeSourceFactory::defaultFactory());
+        Q3SimpleRichText rheading (i18n("<h1>KDE Sys-V Init Editor Log</h1>"),
+                                  QFont("times"), QString(), ksv::styleSheet(),
+                                  Q3MimeSourceFactory::defaultFactory());
         rheading.setWidth (&p, width);
         int tmp_h = rheading.height();
         QRegion region (0, y, width, tmp_h);
@@ -775,9 +782,9 @@ void KSVTopLevel::printLog()
 
         y += tmp_h;
 
-        QSimpleRichText rdate (i18n("<h3>Printed on %1</h3><br/><br/>").arg(KGlobal::locale()->formatDateTime(QDateTime::currentDateTime())),
-                               QFont("times"), QString::null, ksv::styleSheet(),
-                               QMimeSourceFactory::defaultFactory());
+        Q3SimpleRichText rdate (i18n("<h3>Printed on %1</h3><br/><br/>", KGlobal::locale()->formatDateTime(QDateTime::currentDateTime())),
+                               QFont("times"), QString(), ksv::styleSheet(),
+                               Q3MimeSourceFactory::defaultFactory());
         rdate.setWidth (&p, width);
         tmp_h = rdate.height();
 	QRegion r2 (0, y, width, tmp_h);
@@ -790,8 +797,8 @@ void KSVTopLevel::printLog()
         {
           while (y < height)
             {
-              QSimpleRichText rich (*line, QFont("times"), QString::null, ksv::styleSheet(),
-                                    QMimeSourceFactory::defaultFactory());
+              Q3SimpleRichText rich (*line, QFont("times"), QString(), ksv::styleSheet(),
+                                    Q3MimeSourceFactory::defaultFactory());
               rich.setWidth (&p, width);
 
               int tmp_h = rich.height();
@@ -807,7 +814,7 @@ void KSVTopLevel::printLog()
               if (line == lines.end())
                 goto printing_finished;
 
-              kapp->processEvents();
+              qApp->processEvents();
             }
 
           prt->newPage();
@@ -820,6 +827,7 @@ void KSVTopLevel::printLog()
 
       KBusyManager::self()->restore();
       delete prt;
+      delete printDialog;
     }
 }
 
@@ -890,7 +898,7 @@ void KSVTopLevel::dispatchEdit ()
 	}
   else
 	{
-	  QMimeSource* mime = kapp->clipboard()->data();
+	  QMimeSource* mime = QApplication::clipboard()->data();
 
 	  if (mime && mime->provides ("application/x-ksysv"))
 		setPaste (true);
@@ -933,7 +941,7 @@ void KSVTopLevel::slotSaveLog()
 
   QFile file(filename);
 
-  file.open( IO_WriteOnly | IO_Raw );
+  file.open( QIODevice::WriteOnly | IO_Raw );
   QTextStream s(&file);
 
   s << "KDE System V Init Editor"
@@ -954,7 +962,7 @@ void KSVTopLevel::enableLogActions ()
 
 void KSVTopLevel::setCaption (bool changed)
 {
-  setPlainCaption (kapp->makeStdCaption(KNetwork::KResolver::localHostName(), true, changed));
+  setCaption(KNetwork::KResolver::localHostName(), changed);
 }
 
 KActionCollection* KSVTopLevel::filteredActions ()
@@ -980,7 +988,7 @@ void KSVTopLevel::configureKeys ()
 
 void KSVTopLevel::configureToolbars ()
 {
-  KEditToolbar dlg(filteredActions(), xmlFile(), true, this);
+  KEditToolBar dlg(filteredActions(), xmlFile(), true, this);
   connect(&dlg, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ));
   dlg.exec();
 }
@@ -1047,7 +1055,7 @@ void KSVTopLevel::saveAs ()
   // we're busy
   KBusyManager::self()->setBusy (true);
 
-  file.open (IO_WriteOnly | IO_Raw);
+  file.open (QIODevice::WriteOnly | IO_Raw);
   QDataStream s (&file);
 
   if (ksv::IO::saveConfiguration (s, mView->startRL, mView->stopRL))
@@ -1056,7 +1064,7 @@ void KSVTopLevel::saveAs ()
     }
   else
     {
-      kdDebug(3000) << "ERROR saving file" << endl;
+      kDebug(3000) << "ERROR saving file";
     }
 
   file.close();
@@ -1075,10 +1083,10 @@ void KSVTopLevel::load ()
   QFile file(filename);
   KBusyManager::self()->setBusy (true);
 
-  file.open (IO_ReadOnly | IO_Raw);
+  file.open (QIODevice::ReadOnly | IO_Raw);
   QDataStream s (&file);
-  QValueList<KSVData>* startLists = new QValueList<KSVData>[ksv::runlevelNumber];
-  QValueList<KSVData>* stopLists = new QValueList<KSVData>[ksv::runlevelNumber];
+  Q3ValueList<KSVData>* startLists = new Q3ValueList<KSVData>[ksv::runlevelNumber];
+  Q3ValueList<KSVData>* stopLists = new Q3ValueList<KSVData>[ksv::runlevelNumber];
 
   if (ksv::IO::loadSavedConfiguration (s, startLists, stopLists))
     {
@@ -1087,7 +1095,7 @@ void KSVTopLevel::load ()
     }
   else
     {
-      kdDebug (3000) << "ERROR loading file" << endl;
+      kDebug (3000) << "ERROR loading file";
     }
 
   file.close();
