@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -32,7 +32,7 @@
  *  Constructs a KSVPathConfig which is a child of 'parent', with the 
  *  name 'name' and widget flags set to 'f' 
  */
-KSVPathConfig::KSVPathConfig( QWidget* parent,  const char* name, WFlags fl )
+KSVPathConfig::KSVPathConfig( QWidget* parent,  const char* name, Qt::WFlags fl )
     : PathConfiguration( parent, name, fl )
 {
   mSpacer->setFixedHeight (KDialog::spacingHint());
