@@ -3,13 +3,21 @@
     email                : putzer@kde.org
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2.                              *
- *                                                                         *
- ***************************************************************************/
+/*
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -21,8 +29,8 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
+#include <kuniqueapplication.h>
 
-#include "ksvapplication.h"
 #include "ksv_conf.h"
 #include "ksvconfigwizard.h"
 #include "TopWidget.h"
@@ -55,14 +63,14 @@ int main( int argc, char **argv ) {
   // install own message handler that ignores debug-msg when DEBUG is not defined
   qInstallMsgHandler(myMessageOutput);
 
-  KAboutData about("ksysv", I18N_NOOP("SysV-Init Editor"), KSYSV_VERSION_STRING,
-				   I18N_NOOP ("Editor for Sys-V like init configurations"),
+  KAboutData about("ksysv", 0, ki18n("SysV-Init Editor"), KSYSV_VERSION_STRING,
+				   ki18n ("Editor for Sys-V like init configurations"),
 				   KAboutData::License_GPL,
-				   "Copyright (c) 1997-2000, Peter Putzer.",
-				   I18N_NOOP ("Similar to Red Hat's" \
+				   ki18n("Copyright (c) 1997-2000, Peter Putzer."),
+				   ki18n ("Similar to Red Hat's" \
                               "\"tksysv\", but SysV-Init Editor allows\n" \
 			      "drag-and-drop, as well as keyboard use."));
-  about.addAuthor ("Peter Putzer", I18N_NOOP("Main developer"), "putzer@kde.org");
+  about.addAuthor (ki18n("Peter Putzer"), ki18n("Main developer"), "putzer@kde.org");
   ksv::about = &about;
 
   KCmdLineArgs::init(argc, argv, &about);
@@ -73,10 +81,10 @@ int main( int argc, char **argv ) {
     return -1;
   }
 
-  KSVApplication app;
+  KUniqueApplication app;
 
   // session-management
-  if (kapp->isRestored())
+  if (kapp->isSessionRestored())
     RESTORE(KSVTopLevel)
   else
     {
