@@ -19,18 +19,22 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
+
 #include "EditWidget.moc"
 #include "ui.h"
-EditWidget::EditWidget(QString const label, QString const text, bool isFile, QWidget *parent, const char *name, WFlags f, bool allowLines):QHBox(allowLines, parent, name, f)
+//Added by qt3to4:
+#include <QLabel>
+
+EditWidget::EditWidget(QString const label, QString const text, bool isFile, QWidget *parent, const char *name, Qt::WFlags f, bool allowLines):KHBox(parent)
 {
-	setMargin(SPACE_MARGIN);
+	//setMargin(SPACE_MARGIN);
 	setSpacing(SPACE_INSIDE);
 	lbl=new QLabel(label, this);
 	setStretchFactor(lbl, 0);
@@ -49,7 +53,7 @@ EditWidget::EditWidget(QString const label, QString const text, bool isFile, QWi
 }
 void EditWidget::selectFileClicked()
 {
-    QString filename=FileDlg::getOpenFileName(QString::null, QString::null, this);
+    QString filename=FileDlg::getOpenFileName(KUrl(), QString(), this);
     if(!filename.isEmpty())
 	line->setText(filename);
 }
