@@ -24,21 +24,23 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
+
 #ifndef _GENERAL_H_
 #define _GENERAL_H_ 1
 #include <lilo.h>
-#include <qwidget.h>
-#include <qcombobox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
+#include <QWidget>
+#include <QComboBox>
+#include <QSpinBox>
+#include <QCheckBox>
+
 class General:public QWidget
 {
 	Q_OBJECT
 public:
-	General(liloconf *l=0, QWidget *parent=0, const char *name=0);
-    void makeReadOnly();
+	explicit General(liloconf *l=0, QWidget *parent=0);
+	void makeReadOnly();
 signals:
 	void configChanged();
 public slots:
