@@ -22,21 +22,22 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
 
 #ifndef _STANDALONE_H_
 #define _STANDALONE_H_ 1
-#include <qwidget.h>
-#include <qpushbutton.h>
+#include <QWidget>
+#include <QPushButton>
 #include <qhbuttongroup.h>
 #include <qevent.h>
 #include "mainwidget.h"
+
 class Standalone: public QWidget
 {
 	Q_OBJECT
 public:
-	Standalone(QWidget *parent=0, const char *name=0);
+	explicit Standalone(QWidget *parent=0, const char *name=0);
 	void resizeEvent(QResizeEvent *e);
 public slots:
 	void whatsthis();
